@@ -1,3 +1,8 @@
+#[allow(dead_code)]
+mod array_buf;
+pub(crate) use array_buf::*;
+
+#[allow(dead_code)]
 mod array_or_vec;
 pub(crate) use array_or_vec::*;
 
@@ -6,8 +11,8 @@ mod retry;
 pub(crate) use retry::*;
 
 #[allow(dead_code)]
-mod uninit_buf;
-pub(crate) use uninit_buf::*;
+mod win_path_buf_utils;
+pub(crate) use win_path_buf_utils::*;
 
 mod range;
 pub(crate) use range::*;
